=====================
Qa Analytics Insights
=====================


.. figure:: https://img.shields.io/badge/qa_analytics_insights-<version>-blue
    :alt: qa-analytics-insights release
    :target: https://www.github.com/aydabd/qa-analytics-insights/releases
    :name: qa_analytics_insights_release

.. rtfd-shield::
    :project: qa-analytics-insights

.. pre-commit-shield::

.. figure:: https://github.com/aydabd/qa-analytics-insights/actions/workflows/ci.yml/badge.svg
      :alt: GitHub Workflow Status
      :target: https://www.github.com/aydabd/qa-analytics-insights/actions/workflows/ci.yml

Contents
========

.. toctree::
   :maxdepth: 2
   :numbered:

   Overview <readme>
   License <license>
   Authors <authors>
   Modules <api/modules>


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
